@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,21 +14,24 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides the PresentationManager class for Orca."""
 
-__id__        = "$Id: presentation_manager.py 1533 2006-10-06 07:59:04Z richb $"
-__version__   = "$Revision: 1533 $"
-__date__      = "$Date: 2006-10-06 03:59:04 -0400 (Fri, 06 Oct 2006) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__ = "$Id: presentation_manager.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 class PresentationManager:
     """High level manager for reacting to user input events and
     presenting information to the user."""
 
+    def __init__(self):
+        pass
+
     def processKeyboardEvent(self, keyboardEvent):
         """Called when a key is pressed on the keyboard.
 
