@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4508 2009-02-08 19:40:32Z wwalker $"
-__version__   = "$Revision: 4508 $"
-__date__      = "$Date: 2009-02-08 14:40:32 -0500 (Sun, 08 Feb 2009) $"
+__id__        = "$Id: settings.py 4383 2008-12-06 21:29:39Z joanied $"
+__version__   = "$Revision: 4383 $"
+__date__      = "$Date: 2008-12-06 16:29:39 -0500 (Sat, 06 Dec 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -713,30 +713,6 @@ textAttributesBrailleIndicator = TEXT_ATTR_BRAILLE_NONE
 #
 repeatCharacterLimit = 4
 
-# Tags associated with ARIA landmarks.
-#
-ariaLandmarks = [
-    "application",
-    "article",
-    "banner",
-    "complementary",
-    "contentinfo",
-    "definition",
-    "directory",
-    "document",
-    "grid",
-    "log",
-    "main",
-    "menubar",
-    "navigation",
-    "note",
-    "region",
-    "search",
-    "secondary",
-    "seealso",
-    "status",
-]
-
 # Script developer feature.  If False, just the default script
 # will be used.  Helps determine difference between custom
 # scripts and the default script behavior.
